<?php
/*
Plugin Name: TeamBooking Content Hook - Example 2 (tbk_email_hook_replace)
Description: Add a "genitive" case to the Customer's first name (German language). It is just a documentation example, take it as a starting point.
Version:     1.0
Author:      VonStroheim
License:     MIT
License URI: https://opensource.org/licenses/MIT
*/

function example_one_tbk_email_hook_replace($value, $hook, $all_values)
{
    /* The $hook variable is the current hook intercepted by TeamBooking,
     * basically every text between square brackets is a hook. So we need
     * to check when this hook is equal to our "first_name_genitive" (we must
     * have placed it in the e-mail template, of course, otherwise it won't be here).
     *
     * The $value is the text that TeamBooking will render at the hook's place.
     * If the hook is not recognized by TeamBooking (i.e. our custom one)
     * then $value will be the hook text itself (i.e. it won't be modified).
     *
     * The $all_values is an array ("hook" => "value") of all the values
     * known by TeamBooking, that are ready to be rendered.
     *
     * Our function must ALWAYS return the text that should be rendered
     * at the current hook's place.
     */

    if (trim($hook, '[]') === 'first_name_genitive') {

        // That's our hook... let's retrieve the customer's first name
        $first_name = $all_values['first_name'];

        // Let's code out German genitive case logic
        if (preg_match('/(s|ß|z|x|ce)$/', $first_name)) {

            // Return the wanted replacement text of current "first_name_genitive" hook
            return $first_name . "'";

        } else {
            // Return the wanted replacement text of current "first_name_genitive" hook
            return $first_name . "'s";

        }
    } else {

        // That's not our hook, so just return its default $value. If we forget
        // to return it, then all the other hooks will be replaced by an empty string!!
        return $value;
    }
}

add_action('tbk_email_hook_replace', 'example_one_tbk_email_hook_replace', 10, 3);